onDirectionChanged property

ValueChanged<TextDirection>? onDirectionChanged
final

Callback that is called when the text direction changes.

This callback is triggered when the text direction is automatically detected based on the content and changes from LTR to RTL or vice versa.

The callback always receives a non-null TextDirection. When the field is empty or the content is directionally neutral, the ambient Directionality.of value is used as the fallback direction.

Implementation

final ValueChanged<TextDirection>? onDirectionChanged;